#
# spec file for package gcc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gcc
%define separate_bi32 0
%define separate_bi64 0
%ifarch ppc
%define separate_bi64 1
%endif
%ifarch x86_64 s390x ppc64
%define separate_bi32 1
%endif
# Ada currently fails to build on a few platforms, enable it only
# on those that work
# Note that AdaCore only supports %ix86, x86_64 and ia64
%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x ia64 aarch64
%define build_ada 1
%else
# alpha hppa arm
%define build_ada 0
%endif
Url:            http://gcc.gnu.org/
%define gcc_version 7
%define gcc_suffix 7
Version:        7
Release:        lp150.2.3.1
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Provides:       c_compiler
Obsoletes:      gcc-ar
Obsoletes:      gcc-mudflap
Obsoletes:      gcc-nm
Obsoletes:      gcc-ranlib
Requires:       cpp
Requires:       gcc%{gcc_version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc%{gcc_version}
Source:         cpp

%description
The system GNU C Compiler.



%package -n gcc-32bit
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-32bit

%description -n gcc-32bit
The system GNU C Compiler.



%package -n gcc-64bit
Summary:        The system GNU C Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-64bit

%description -n gcc-64bit
The system GNU C Compiler.



%package -n cpp
Summary:        The system GNU Preprocessor
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       cpp%{gcc_version}

%description -n cpp
The system GNU Preprocessor.


%package -n gcc-devel
Summary:        The system GNU C Compiler Plugin development files
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-devel

%description -n gcc-devel
The system GNU C Compiler Plugin development files.


%package -n gcc-locale
Summary:        The system GNU Compiler locale files
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-locale

%description -n gcc-locale
The system GNU Compiler locale files.



%package -n gcc-info
Summary:        The system GNU Compiler documentation
License:        GFDL-1.2
Group:          Development/Languages/C and C++
PreReq:         %{install_info_prereq}
PreReq:         gcc%{gcc_version}-info

%description -n gcc-info
The system GNU Compiler documentation.

# install / update the entries
%post -n gcc-info
%install_info --info-dir=%{_infodir} --name=cpp --description='The GNU C preprocessor.' %{_infodir}/cpp.info.gz
%install_info --info-dir=%{_infodir} --name=gcc --description='The GNU Compiler Collection.' %{_infodir}/gcc.info.gz
%install_info --info-dir=%{_infodir} --name=g++ --description='The GNU C++ compiler.' %{_infodir}/gcc.info.gz
%install_info --info-dir=%{_infodir} --name=gfortran --description='The GNU Fortran compiler.' %{_infodir}/gfortran.info.gz

# if we uninstall, clean the entries
%preun -n gcc-info
if [ "$1" -eq "0" ] ; then
  %install_info --delete --info-dir=%{_infodir} --name=cpp %{_infodir}/cpp.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=gcc %{_infodir}/gcc.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=g++ %{_infodir}/gcc.info.gz
  %install_info --delete --info-dir=%{_infodir} --name=gfortran %{_infodir}/gfortran.info.gz
fi

%package -n gcc-c++
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Provides:       c++_compiler
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-c++

%description -n gcc-c++
The system GNU C++ Compiler.


%package -n gcc-c++-32bit
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-c++-32bit
Requires:       gcc-32bit = %{version}
Requires:       gcc-c++ = %{version}

%description -n gcc-c++-32bit
The system GNU C++ Compiler 32 bit support.


%package -n gcc-c++-64bit
Summary:        The system GNU C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-c++-64bit
Requires:       gcc-64bit = %{version}
Requires:       gcc-c++ = %{version}

%description -n gcc-c++-64bit
The system GNU C++ Compiler 64 bit support.



%package -n libstdc++-devel
Summary:        The system GNU C++ development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++6-devel-gcc%{gcc_version}

%description -n libstdc++-devel
The system GNU C++ development files.


%package -n libstdc++-devel-32bit
Summary:        The system GNU C++ 32bit development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++-devel
Requires:       libstdc++6-devel-gcc%{gcc_version}-32bit

%description -n libstdc++-devel-32bit
The system GNU C++ 32bit development files.


%package -n libstdc++-devel-64bit
Summary:        The system GNU C++ 64bit development files
License:        GPL-3.0-with-GCC-exception
Group:          System/Libraries
Requires:       libstdc++-devel
Requires:       libstdc++6-devel-gcc%{gcc_version}-64bit

%description -n libstdc++-devel-64bit
The system GNU C++ 64bit development files.



%package -n gcc-fortran
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-fortran

%description -n gcc-fortran
The system GNU Fortran Compiler.


%package -n gcc-fortran-32bit
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc%{gcc_version}-fortran-32bit
Requires:       gcc-fortran = %{version}

%description -n gcc-fortran-32bit
The system GNU Fortran Compiler 32 bit support.


%package -n gcc-fortran-64bit
Summary:        The system GNU Fortran Compiler
License:        GPL-3.0+
Group:          Development/Languages/Fortran
Requires:       gcc%{gcc_version}-fortran-64bit
Requires:       gcc-fortran = %{version}

%description -n gcc-fortran-64bit
The system GNU Fortran Compiler 64 bit support.



%package -n gcc-objc
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-objc
%ifarch ppc64
Obsoletes:      gcc-objc-64bit
%endif

%description -n gcc-objc
The system GNU Objective C Compiler.



%package -n gcc-objc-32bit
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-objc-32bit
Requires:       gcc-objc = %{version}

%description -n gcc-objc-32bit
The system GNU Objective C Compiler 32 bit support.



%package -n gcc-objc-64bit
Summary:        The system GNU Objective C Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-objc-64bit
Requires:       gcc-objc = %{version}

%description -n gcc-objc-64bit
The system GNU Objective C Compiler 64 bit support.



%package -n gcc-obj-c++
Summary:        The system GNU Objective C++ Compiler
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc%{gcc_version}-obj-c++
Requires:       gcc-objc = %{version}

%description -n gcc-obj-c++
The system GNU Objective C++ Compiler.



%package -n gcc-PIE
Summary:        A default configuration to build all binaries in PIE mode
License:        GPL-3.0+
Group:          Development/Languages/Other
Requires:       gcc

%description -n gcc-PIE
This package contains a configuration file (spec) that changes the
compilers default setting to build all ELF binaries in the Position
Independend Executable (PIE) variant. This enables better address
space randomization (ASLR).


%package -n gcc-ada
Summary:        The system GNU Ada Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-ada

%description -n gcc-ada
The system GNU Ada Compiler.

%package -n gcc-ada-32bit
Summary:        The system GNU Ada Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-ada-32bit
Requires:       gcc-ada = %{version}

%description -n gcc-ada-32bit
The system GNU Ada Compiler 32 bit support.

%package -n gcc-ada-64bit
Summary:        The system GNU Ada Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-ada-64bit
Requires:       gcc-ada = %{version}

%description -n gcc-ada-64bit
The system GNU Ada Compiler 64 bit support.


%package -n gcc-go
Summary:        The system GNU Go Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc = %{version}
Requires:       gcc%{gcc_version}-go

%description -n gcc-go
The system GNU Go Compiler.

%package -n gcc-go-32bit
Summary:        The system GNU Go Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-go-32bit
Requires:       gcc-go = %{version}

%description -n gcc-go-32bit
The system GNU Go Compiler 32bit support.

%package -n gcc-go-64bit
Summary:        The system GNU Go Compiler
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Requires:       gcc%{gcc_version}-go-64bit
Requires:       gcc-go = %{version}

%description -n gcc-go-64bit
The system GNU Go Compiler 64bit support.


%prep 

%install
mkdir -p $RPM_BUILD_ROOT/lib
mkdir -p $RPM_BUILD_ROOT%{_prefix}/bin
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
mkdir -p $RPM_BUILD_ROOT%{_infodir}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/share/doc/packages/gcc-objc/
mkdir -p $RPM_BUILD_ROOT%{_prefix}/share/doc/packages/gcc-obj-c++/
# Link all the binaries
for program in \
        gcc gcov gcov-dump gcov-tool \
        g++ \
        cpp \
        gfortran \
%if %{build_ada}
	gnat gnatbind gnatbl gnatchop gnatclean gnatfind gnatkr \
	gnatlink gnatls gnatmake gnatname gnatprep gnatxref gprmake \
%endif
	gcc-ar gcc-nm gcc-ranlib \
    ; do
  ln -sf $program-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/$program
done
# Link section 1 manpages
for man1 in \
        gcc gcov gcov-dump gcov-tool \
        g++ \
        cpp \
        gfortran \
    ; do
  ln -sf $man1-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/$man1.1.gz
done
# Link info pages
for info in cpp gcc gfortran ; do
  ln -sf $info-%{gcc_suffix}.info.gz $RPM_BUILD_ROOT%{_infodir}/$info.info.gz
done
# Provide the traditional /lib/cpp that only handles C
cp $RPM_SOURCE_DIR/cpp $RPM_BUILD_ROOT/lib/
chmod 755 $RPM_BUILD_ROOT/lib/cpp
# Provide extra symlinks
ln -sf g++-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/c++
ln -sf gcc-%{gcc_suffix} $RPM_BUILD_ROOT%{_prefix}/bin/cc
ln -sf g++-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/c++.1.gz
ln -sf gcc-%{gcc_suffix}.1.gz $RPM_BUILD_ROOT%{_mandir}/man1/cc.1.gz
# Install the LTO linker plugin so it is auto-loaded by BFD
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib/bfd-plugins
ln -s `gcc-%{gcc_suffix} -print-file-name=liblto_plugin.so.0.0.0` $RPM_BUILD_ROOT%{_prefix}/lib/bfd-plugins/liblto_plugin.so.0.0.0

dir=`gcc-%{gcc_suffix} -print-prog-name=cc1`
dir=${dir%/cc1}
mkdir -p $RPM_BUILD_ROOT/$dir
cat > $RPM_BUILD_ROOT/$dir/defaults.spec <<EOF
*default_spec:
%%{pie|fpic|fPIC|fpie|fPIE|no-pie|fno-pic|fno-PIC|fno-pie|fno-PIE|shared|static|nostdlib|nodefaultlibs|nostartfiles:;:-fPIE -pie}
EOF

%files
%defattr(-,root,root)
%{_prefix}/bin/gcc
%{_prefix}/bin/cc
%{_prefix}/bin/gcov
%{_prefix}/bin/gcov-dump
%{_prefix}/bin/gcov-tool
%{_prefix}/bin/gcc-ar
%{_prefix}/bin/gcc-nm
%{_prefix}/bin/gcc-ranlib
%dir %{_prefix}/lib/bfd-plugins
%{_prefix}/lib/bfd-plugins/liblto_plugin.so.0.0.0
%doc %{_mandir}/man1/gcc.1.gz
%doc %{_mandir}/man1/cc.1.gz
%doc %{_mandir}/man1/gcov.1.gz
%doc %{_mandir}/man1/gcov-dump.1.gz
%doc %{_mandir}/man1/gcov-tool.1.gz

%files -n cpp
%defattr(-,root,root)
/lib/cpp
%{_prefix}/bin/cpp
%doc %{_mandir}/man1/cpp.1.gz

# Plugins are only enabled for Tumbleweed
%if 0%{!?sle_version:1}
%files -n gcc-devel
%defattr(-,root,root)
# empty - only for the dependency
%endif

%files -n gcc-c++
%defattr(-,root,root)
%{_prefix}/bin/g++
%{_prefix}/bin/c++
%doc %{_mandir}/man1/g++.1.gz
%doc %{_mandir}/man1/c++.1.gz

%files -n gcc-fortran
%defattr(-,root,root)
%{_prefix}/bin/gfortran
%doc %{_mandir}/man1/gfortran.1.gz

%files -n gcc-objc
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-obj-c++
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-PIE
%defattr(-,root,root)
/usr/lib*/gcc/*-suse-linux*/*/defaults.spec

%files -n gcc-locale
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-info
%defattr(-,root,root)
%{_infodir}/cpp.info.gz
%{_infodir}/gcc.info.gz
%{_infodir}/gfortran.info.gz

%if %{build_ada}
%files -n gcc-ada
%defattr(-,root,root)
%{_prefix}/bin/gnat
%{_prefix}/bin/gnatbind
%{_prefix}/bin/gnatbl
%{_prefix}/bin/gnatchop
%{_prefix}/bin/gnatclean
%{_prefix}/bin/gnatfind
%{_prefix}/bin/gnatkr
%{_prefix}/bin/gnatlink
%{_prefix}/bin/gnatls
%{_prefix}/bin/gnatmake
%{_prefix}/bin/gnatname
%{_prefix}/bin/gnatprep
%{_prefix}/bin/gnatxref
%{_prefix}/bin/gprmake
%endif

%files -n libstdc++-devel
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-go
%defattr(-,root,root)
# empty - only for the dependency

%if %{separate_bi32}

%files -n gcc-32bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-c++-32bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n libstdc++-devel-32bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-fortran-32bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-objc-32bit
%defattr(-,root,root)
# empty - only for the dependency

%if %{build_ada}
%files -n gcc-ada-32bit
%defattr(-,root,root)
# empty - only for the dependency
%endif

%files -n gcc-go-32bit
%defattr(-,root,root)
# empty - only for the dependency

%endif
%if %{separate_bi64}

%files -n gcc-64bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-c++-64bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n libstdc++-devel-64bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-fortran-64bit
%defattr(-,root,root)
# empty - only for the dependency

%files -n gcc-objc-64bit
%defattr(-,root,root)
# empty - only for the dependency

%if %{build_ada}
%files -n gcc-ada-64bit
%defattr(-,root,root)
# empty - only for the dependency
%endif

%files -n gcc-go-64bit
%defattr(-,root,root)
# empty - only for the dependency

%endif

%changelog
* Tue Jun  5 2018 rguenther@suse.com
- Fix gcc-PIE spec to properly honor -no-pie at link time.
  [bnc#1096008]
* Fri Jun  9 2017 rguenther@suse.com
- Fix gcc-devel guard to use %%sle_version.  [bnc#1043590]
* Wed Jun  7 2017 rguenther@suse.com
- Guard gcc-devel so it is only built on Tumbleweed.
- Remove bogus link to versioned g++.info file which doesn't exist.
  Instead refer to gcc.info from the g++ info directory entry.
  [bnc#922419]
* Tue Jun  6 2017 mliska@suse.cz
- Include gcov-tool and gcov-dump binaries.
* Thu Apr 13 2017 rguenther@suse.com
- Remove README in empty packages only required for SLE11 and older.
- Remove now empty %%build section.
* Tue Apr  4 2017 rguenther@suse.com
- Fix dependencies of libstdc++-devel-{32,64}-bit.
* Thu Mar 23 2017 rguenther@suse.com
- Switch gcc to default 7.
- Remove unrelated README.packaging.
* Fri Feb 10 2017 rguenther@suse.com
- Enable Ada for s390x.
* Mon Jan 23 2017 rguenther@suse.com
- Remove java related packages, those are in a separate gcc-java now.
* Thu Aug 18 2016 rguenther@suse.com
- Add gcc-devel package.
* Wed Apr 27 2016 rguenther@suse.com
- Switch gcc to default 6.
* Thu Apr 14 2016 rguenther@suse.com
- Enable Ada for ppc64le and aarch64.
* Thu May 21 2015 rguenther@suse.com
- Properly query gcc-%%gcc_suffix for paths.
* Tue May 19 2015 rguenther@suse.com
- Fix bogus requires to gcc5-c++-{32,64}bit.
* Fri May  8 2015 rguenther@suse.com
- Adjust for GCC 5 package renames.
* Mon Apr 20 2015 rguenther@suse.com
- Switch gcc to default 5.
- Add gcc-go{,-32bit,-64bit} packages.
* Mon Mar  2 2015 schwab@suse.de
- Add gcc-ada-32bit and gcc-ada-64bit packages only if building Ada
* Wed Feb 25 2015 rguenther@suse.com
- Add gcc-ada-32bit and gcc-ada-64bit packages.
* Wed Feb  4 2015 meissner@suse.com
- add a gcc-PIE subpackage, which enables building PIE binaries
  by default using the defaults.spec file. bsc#912298
* Mon Aug  4 2014 rguenther@suse.com
- Add libstdc++-devel-32bit and libstdc++-devel-64bit packages.
  [bnc#890226]
* Fri Mar 21 2014 rguenther@suse.com
- Link to the system compiler LTO plugin from /usr/lib/bfd-plugins.
* Tue Feb  4 2014 rguenther@suse.com
- Remove gcc-z9 wrapper which is obsolete.
* Mon Dec  2 2013 rguenther@suse.com
- Move gcc-ar, gcc-nm and gcc-ranlib to the gcc package instead
  of packaging them separately.
* Wed Jun 19 2013 rguenther@suse.com
- Package gcc-ar, gcc-nm and gcc-ranlib wrapping ar, nm and ranlib
  in a plugin-aware fashion.
* Mon May 27 2013 rguenther@suse.com
- Switch gcc to default 4.8.
* Mon Jan  7 2013 rguenther@suse.com
- Re-enable Ada for ppc64.
* Thu Dec 13 2012 rguenther@suse.com
- Add BuildRequires to gcc$version, required for cc1 path detection.
* Wed Nov 28 2012 rguenther@suse.com
- Rework gcc-info.
  * Install symlinks to the versioned info files and adjust
    install_info calls.  [bnc#756182]
  * Provide uninstall hook that removes the alias entries.
* Thu Oct  4 2012 dmueller@suse.com
- remove gcc-ada subpackage for those architectures that
  don't have a gccXX-ada package
* Wed Apr 18 2012 rguenther@suse.com
- Switch gcc to default 4.7.
* Fri Jan 27 2012 rguenther@suse.com
- Change licenses to follow SPDX convention.
* Mon Sep 26 2011 dmueller@suse.de
- use the target gcc binary for finding the right cc1 path
* Wed May 11 2011 rguenther@novell.com
- Switch gcc to default 4.6.
* Thu Feb 10 2011 rguenther@novell.com
- Fix licenses to match those of the system compiler.  [bnc#670658]
* Tue Jan 25 2011 rguenther@novell.com
- Fix string quoting.  [bnc#666416]
* Wed Jan 12 2011 rguenther@novell.com
- Uglify spec file formatting.
* Fri Dec 10 2010 rguenther@novell.com
- Add info directory aliases for unversioned variants of the
  GCC user manuals.  [bnc#635355]
* Mon Nov 29 2010 rguenther@novell.com
- Drop libffi packages.
* Fri Feb 26 2010 rguenther@novell.com
- Fix gcc-c++-32bit and gcc-c++-64bit again.
* Thu Feb 25 2010 rguenther@suse.de
- Drop c++_compiler provides from gcc-c++-32bit and gcc-c++-64bit.
* Thu Feb 25 2010 rguenther@suse.de
- Re-add gcc-c++-32bit and gcc-c++-64bit packages.
* Tue Feb 16 2010 coolo@novell.com
- Switch gcc to default 4.5.
* Mon Apr 27 2009 rguenther@suse.de
- Switch gcc default to 4.4.
* Mon Feb 16 2009 rguenther@suse.de
- Enable links for classpath binaries and manpages again.
* Fri Jan  9 2009 rguenther@suse.de
- On ppc64 obsolete gcc-objc-64bit by gcc-objc.
* Thu Dec  4 2008 matz@suse.de
- Add new gcc-z9 package on s390 and s390x to change the
  default -march and -mtune settings.
* Wed May  7 2008 rguenther@suse.de
- Make dependencies between the gcc subpackages versioned. [bnc#385305]
* Fri Nov 23 2007 rguenther@suse.de
- Make gcc-gij dependency of gcc-java a recommendation, all java
  tools are back to the gcc-java package.  Require libgcj-devel
  from gcc-java.
- Revert /lib/cpp changes.
* Fri Nov 16 2007 rguenther@suse.de
- For now disable symlinking of binaries and manpages that
  conflict with the classpath package.
* Tue Nov 13 2007 rguenther@suse.de
- Make /lib/cpp traditional and avoid GCC and target specific
  defines.
* Tue Oct 30 2007 rguenther@suse.de
- Add gcc-gij dependency to gcc-java as it contains many of the
  tools formerly packaged in the gcc-java package.
* Mon Sep 24 2007 rguenther@suse.de
- Switch gcc default to 4.3.
* Fri Jul 27 2007 rguenther@suse.de
- Fix typo.
* Tue Jul 24 2007 rguenther@suse.de
- Add 32bit and 64bit variants of gcc-gij.  [#293423]
* Fri Jul  6 2007 rguenther@suse.de
- Mark ppc64 as separate bi-32.
* Thu Jun 14 2007 ro@suse.de
- Do not mark README.packaging as NoSource. (again)
* Fri Jun  8 2007 rguenther@suse.de
- Switch gcc default to 4.2.  [#275939]
* Tue Apr 24 2007 rguenther@suse.de
- Do not link to grmic and grmiregistry, they conflict with
  the classpath package versions.
* Tue Jan 16 2007 rguenther@suse.de
- Do not mark README.packaging as NoSource.
* Thu Nov  9 2006 rguenther@suse.de
- Remove gcc-c++-32bit and gcc-c++-64bit packages.
* Tue Oct 31 2006 dmueller@suse.de
- don't build as root
* Mon Oct 30 2006 rguenther@suse.de
- Make gcc architecture dependent again.  [#215971]
* Thu Oct 26 2006 rguenther@suse.de
- Add dependencies to the gcc and non-32/64bit packages.  [#215217]
* Tue Sep 19 2006 rguenther@suse.de
- New gcc-gij package.
* Fri Aug 25 2006 rguenther@suse.de
- Add 32bit and 64bit support packages to gcc, gcc-c++, gcc-fortran,
  gcc-objc and libffi-devel.
* Thu Aug 24 2006 rguenther@suse.de
- Make gcc require cpp to pull in /lib/cpp.
* Fri Aug 18 2006 rguenther@suse.de
- gcc obsoletes gcc-mudflap which is no longer.
* Mon Aug  7 2006 rguenther@suse.de
- Provide gcc-mudflap, gcc-info and gcc-locale packages [#197515].
* Fri Jul 14 2006 rguenther@suse.de
- New package.
